@@ -464,6 +464,16 @@ NL80211_ATTR_COLOR_CHANGE_ELEMS = 305
 NL80211_ATTR_MBSSID_CONFIG = 306
 NL80211_ATTR_MBSSID_ELEMS = 307
 
+NL80211_ATTR_CQM_RSSI_THOLD = 1
+NL80211_ATTR_CQM_RSSI_HYST = 2
+NL80211_ATTR_CQM_RSSI_THRESHOLD_EVENT = 3
+NL80211_ATTR_CQM_PKT_LOSS_EVENT = 4
+NL80211_ATTR_CQM_TXE_RATE = 5
+NL80211_ATTR_CQM_TXE_PKTS = 6
+NL80211_ATTR_CQM_TXE_INTVL = 7
+NL80211_ATTR_CQM_BEACON_LOSS_EVENT = 8
+NL80211_ATTR_CQM_RSSI_LEVEL = 9
+
 NL80211_ATTR_REG_RULE_FLAGS = 1
 NL80211_ATTR_FREQ_RANGE_START = 2
 NL80211_ATTR_FREQ_RANGE_END = 3
@@ -495,6 +505,27 @@ NL80211_BAND_IFTYPE_ATTR_VENDOR_ELEMS = 7
 NL80211_BITRATE_ATTR_RATE = 1
 NL80211_BITRATE_ATTR_2GHZ_SHORTPREAMBLE = 2
 
+NL80211_BSS_BSSID = 1
+NL80211_BSS_FREQUENCY = 2
+NL80211_BSS_TSF = 3
+NL80211_BSS_BEACON_INTERVAL = 4
+NL80211_BSS_CAPABILITY = 5
+NL80211_BSS_INFORMATION_ELEMENTS = 6
+NL80211_BSS_SIGNAL_MBM = 7
+NL80211_BSS_SIGNAL_UNSPEC = 8
+NL80211_BSS_STATUS = 9
+NL80211_BSS_SEEN_MS_AGO = 10
+NL80211_BSS_BEACON_IES = 11
+NL80211_BSS_CHAN_WIDTH = 12
+NL80211_BSS_BEACON_TSF = 13
+NL80211_BSS_PRESP_DATA = 14
+NL80211_BSS_LAST_SEEN_BOOTTIME = 15
+NL80211_BSS_PAD = 16
+NL80211_BSS_PARENT_TSF = 17
+NL80211_BSS_PARENT_BSSID = 18
+NL80211_BSS_CHAIN_SIGNAL = 19
+NL80211_BSS_FREQUENCY_OFFSET = 20
+
 NL80211_FREQUENCY_ATTR_FREQ = 1
 NL80211_FREQUENCY_ATTR_DISABLED = 2
 NL80211_FREQUENCY_ATTR_NO_IR = 3
@@ -534,6 +565,20 @@ NL80211_IFACE_LIMIT_UNSPEC = 0
 NL80211_IFACE_LIMIT_MAX = 1
 NL80211_IFACE_LIMIT_TYPES = 2
 
+NL80211_KEY_DATA = 1
+NL80211_KEY_IDX = 2
+NL80211_KEY_CIPHER = 3
+NL80211_KEY_SEQ = 4
+NL80211_KEY_DEFAULT = 5
+NL80211_KEY_DEFAULT_MGMT = 6
+NL80211_KEY_TYPE = 7
+NL80211_KEY_DEFAULT_TYPES = 8
+NL80211_KEY_MODE = 9
+NL80211_KEY_DEFAULT_BEACON = 10
+
+NL80211_KEY_DEFAULT_TYPE_UNICAST = 1
+NL80211_KEY_DEFAULT_TYPE_MULTICAST = 2
+
 NL80211_MPATH_INFO_FRAME_QLEN = 1
 NL80211_MPATH_INFO_SN = 2
 NL80211_MPATH_INFO_METRIC = 3
@@ -548,29 +593,29 @@ NL80211_PKTPAT_MASK = 1
 NL80211_PKTPAT_PATTERN = 2
 NL80211_PKTPAT_OFFSET = 3
 
-NL80211_RATE_INFO_BITRATE = 0
-NL80211_RATE_INFO_MCS = 1
-NL80211_RATE_INFO_40_MHZ_WIDTH = 2
-NL80211_RATE_INFO_SHORT_GI = 3
-NL80211_RATE_INFO_BITRATE32 = 4
-NL80211_RATE_INFO_VHT_MCS = 5
-NL80211_RATE_INFO_VHT_NSS = 6
-NL80211_RATE_INFO_80_MHZ_WIDTH = 7
-NL80211_RATE_INFO_80P80_MHZ_WIDTH = 8
-NL80211_RATE_INFO_160_MHZ_WIDTH = 9
-NL80211_RATE_INFO_10_MHZ_WIDTH = 10
-NL80211_RATE_INFO_5_MHZ_WIDTH = 11
-NL80211_RATE_INFO_HE_MCS = 12
-NL80211_RATE_INFO_HE_NSS = 13
-NL80211_RATE_INFO_HE_GI = 14
-NL80211_RATE_INFO_HE_DCM = 15
-NL80211_RATE_INFO_HE_RU_ALLOC = 16
+NL80211_RATE_INFO_BITRATE = 1
+NL80211_RATE_INFO_MCS = 2
+NL80211_RATE_INFO_40_MHZ_WIDTH = 3
+NL80211_RATE_INFO_SHORT_GI = 4
+NL80211_RATE_INFO_BITRATE32 = 5
+NL80211_RATE_INFO_VHT_MCS = 6
+NL80211_RATE_INFO_VHT_NSS = 7
+NL80211_RATE_INFO_80_MHZ_WIDTH = 8
+NL80211_RATE_INFO_80P80_MHZ_WIDTH = 9
+NL80211_RATE_INFO_160_MHZ_WIDTH = 10
+NL80211_RATE_INFO_10_MHZ_WIDTH = 11
+NL80211_RATE_INFO_5_MHZ_WIDTH = 12
+NL80211_RATE_INFO_HE_MCS = 13
+NL80211_RATE_INFO_HE_NSS = 14
+NL80211_RATE_INFO_HE_GI = 15
+NL80211_RATE_INFO_HE_DCM = 16
+NL80211_RATE_INFO_HE_RU_ALLOC = 17
 
-NL80211_STA_BSS_PARAM_CTS_PROT = 0
-NL80211_STA_BSS_PARAM_SHORT_PREAMBLE = 1
-NL80211_STA_BSS_PARAM_SHORT_SLOT_TIME = 2
-NL80211_STA_BSS_PARAM_DTIM_PERIOD = 3
-NL80211_STA_BSS_PARAM_BEACON_INTERVAL = 4
+NL80211_STA_BSS_PARAM_CTS_PROT = 1
+NL80211_STA_BSS_PARAM_SHORT_PREAMBLE = 2
+NL80211_STA_BSS_PARAM_SHORT_SLOT_TIME = 3
+NL80211_STA_BSS_PARAM_DTIM_PERIOD = 4
+NL80211_STA_BSS_PARAM_BEACON_INTERVAL = 5
 
 NL80211_STA_FLAG_AUTHORIZED = 1
 NL80211_STA_FLAG_SHORT_PREAMBLE = 2
@@ -624,6 +669,9 @@ NL80211_STA_INFO_AIRTIME_LINK_METRIC = 41
 NL80211_STA_INFO_ASSOC_AT_BOOTTIME = 42
 NL80211_STA_INFO_CONNECTED_TO_AS = 43
 
+NL80211_STA_WME_UAPSD_QUEUES = 1
+NL80211_STA_WME_MAX_SP = 2
+
 NL80211_TID_STATS_RX_MSDU = 1
 NL80211_TID_STATS_TX_MSDU = 2
 NL80211_TID_STATS_TX_MSDU_RETRIES = 3
@@ -680,6 +728,15 @@ NL80211_WOWLAN_TRIG_WAKEUP_TCP_NOMORETOKENS = 17
 NL80211_WOWLAN_TRIG_NET_DETECT = 18
 NL80211_WOWLAN_TRIG_NET_DETECT_RESULTS = 19
 
+NL80211_AUTHTYPE_OPEN_SYSTEM = 0
+NL80211_AUTHTYPE_SHARED_KEY = 1
+NL80211_AUTHTYPE_FT = 2
+NL80211_AUTHTYPE_NETWORK_EAP = 3
+NL80211_AUTHTYPE_SAE = 4
+NL80211_AUTHTYPE_FILS_SK = 5
+NL80211_AUTHTYPE_FILS_SK_PFS = 6
+NL80211_AUTHTYPE_FILS_PK = 7
+
 NL80211_BAND_2GHZ = 0
 NL80211_BAND_5GHZ = 1
 NL80211_BAND_60GHZ = 2
@@ -687,6 +744,10 @@ NL80211_BAND_6GHZ = 3
 NL80211_BAND_S1GHZ = 4
 NL80211_BAND_LC = 5
 
+NL80211_HIDDEN_SSID_NOT_IN_USE = 0
+NL80211_HIDDEN_SSID_ZERO_LEN = 1
+NL80211_HIDDEN_SSID_ZERO_CONTENTS = 2
+
 NL80211_IFTYPE_UNSPECIFIED = 0
 NL80211_IFTYPE_ADHOC = 1
 NL80211_IFTYPE_STATION = 2
@@ -701,6 +762,21 @@ NL80211_IFTYPE_P2P_DEVICE = 10
 NL80211_IFTYPE_OCB = 11
 NL80211_IFTYPE_NAN = 12
 
+NL80211_KEY_RX_TX = 0
+NL80211_KEY_NO_TX = 1
+NL80211_KEY_SET_TX = 2
+
+NL80211_KEYTYPE_GROUP = 0
+NL80211_KEYTYPE_PAIRWISE = 1
+NL80211_KEYTYPE_PEERKEY = 2
+
+NL80211_MNTR_FLAG_FCSFAIL = 1
+NL80211_MNTR_FLAG_PLCPFAIL = 2
+NL80211_MNTR_FLAG_CONTROL = 3
+NL80211_MNTR_FLAG_OTHER_BSS = 4
+NL80211_MNTR_FLAG_COOK_FRAMES = 5
+NL80211_MNTR_FLAG_ACTIVE = 6
+
 NL80211_PROBE_RESP_OFFLOAD_SUPPORT_WPS = 1 << 0
 NL80211_PROBE_RESP_OFFLOAD_SUPPORT_WPS2 = 1 << 1
 NL80211_PROBE_RESP_OFFLOAD_SUPPORT_P2P = 1 << 2
@@ -710,6 +786,18 @@ NL80211_PROBE_RESP_OFFLOAD_SUPPORT_80211U = 1 << 3
 class NL80211(generic.GenericNetlinkSocket):
 	ATTRIBUTES = {} # Forward declaration
 
+	ATTRIBUTES_CQM = {
+		NL80211_ATTR_CQM_RSSI_THOLD: attributes.binary(),
+		NL80211_ATTR_CQM_RSSI_HYST: attributes.u32(),
+		NL80211_ATTR_CQM_RSSI_THRESHOLD_EVENT: attributes.u32(),
+		NL80211_ATTR_CQM_PKT_LOSS_EVENT: attributes.u32(),
+		NL80211_ATTR_CQM_TXE_RATE: attributes.u32(),
+		NL80211_ATTR_CQM_TXE_PKTS: attributes.u32(),
+		NL80211_ATTR_CQM_TXE_INTVL: attributes.u32(),
+		NL80211_ATTR_CQM_BEACON_LOSS_EVENT: attributes.flag(),
+		NL80211_ATTR_CQM_RSSI_LEVEL: attributes.s32()
+	}
+
 	ATTRIBUTES_WMMR = {
 		NL80211_WMMR_CW_MIN: attributes.u16(),
 		NL80211_WMMR_CW_MAX: attributes.u16(),
@@ -943,6 +1031,11 @@ class NL80211(generic.GenericNetlinkSocket):
 		NL80211_STA_INFO_CONNECTED_TO_AS: attributes.u8()
 	}
 	
+	ATTRIBUTES_STA_WME = {
+		NL80211_STA_WME_UAPSD_QUEUES: attributes.u8(),
+		NL80211_STA_WME_MAX_SP: attributes.u8()
+	}
+	
 	ATTRIBUTES_MPATH_INFO = {
 		NL80211_MPATH_INFO_FRAME_QLEN: attributes.u32(),
 		NL80211_MPATH_INFO_SN: attributes.u32(),
@@ -964,6 +1057,47 @@ class NL80211(generic.GenericNetlinkSocket):
 		NL80211_ATTR_POWER_RULE_MAX_EIRP: attributes.u32(),
 		NL80211_ATTR_DFS_CAC_TIME: attributes.u32()
 	}
+	
+	ATTRIBUTES_BSS = {
+		NL80211_BSS_BSSID: attributes.binary(),
+		NL80211_BSS_FREQUENCY: attributes.u32(),
+		NL80211_BSS_TSF: attributes.u64(),
+		NL80211_BSS_BEACON_INTERVAL: attributes.u16(),
+		NL80211_BSS_CAPABILITY: attributes.u16(),
+		NL80211_BSS_INFORMATION_ELEMENTS: attributes.binary(),
+		NL80211_BSS_SIGNAL_MBM: attributes.u32(),
+		NL80211_BSS_SIGNAL_UNSPEC: attributes.u8(),
+		NL80211_BSS_STATUS: attributes.u32(),
+		NL80211_BSS_SEEN_MS_AGO: attributes.u32(),
+		NL80211_BSS_BEACON_IES: attributes.binary(),
+		NL80211_BSS_CHAN_WIDTH: attributes.u32(),
+		NL80211_BSS_BEACON_TSF: attributes.u64(),
+		NL80211_BSS_PRESP_DATA: attributes.flag(),
+		NL80211_BSS_LAST_SEEN_BOOTTIME: attributes.u64(),
+		NL80211_BSS_PAD: attributes.padding(),
+		NL80211_BSS_PARENT_TSF: attributes.u64(),
+		NL80211_BSS_PARENT_BSSID: attributes.binary(),
+		NL80211_BSS_CHAIN_SIGNAL: attributes.array(attributes.u8()),
+		NL80211_BSS_FREQUENCY_OFFSET: attributes.u32()
+	}
+	
+	ATTRIBUTES_KEY_DEFAULT = {
+		NL80211_KEY_DEFAULT_TYPE_UNICAST: attributes.flag(),
+		NL80211_KEY_DEFAULT_TYPE_MULTICAST: attributes.flag()
+	}
+	
+	ATTRIBUTES_KEY = {
+		NL80211_KEY_DATA: attributes.binary(),
+		NL80211_KEY_IDX: attributes.u8(),
+		NL80211_KEY_CIPHER: attributes.u32(),
+		NL80211_KEY_SEQ: attributes.binary(),
+		NL80211_KEY_DEFAULT: attributes.flag(),
+		NL80211_KEY_DEFAULT_MGMT: attributes.flag(),
+		NL80211_KEY_TYPE: attributes.u32(),
+		NL80211_KEY_DEFAULT_TYPES: attributes.nested(ATTRIBUTES_KEY_DEFAULT),
+		NL80211_KEY_MODE: attributes.u8(),
+		NL80211_KEY_DEFAULT_BEACON: attributes.flag()
+	}
 
 	ATTRIBUTES.update({
 		#1 - 34
@@ -1002,15 +1136,20 @@ class NL80211(generic.GenericNetlinkSocket):
 		NL80211_ATTR_REG_ALPHA2: attributes.string(),
 		NL80211_ATTR_REG_RULES: attributes.array(attributes.nested(ATTRIBUTES_REG_RULE)),
 		
-		#41 - 46
+		#38 - 39
+		NL80211_ATTR_WIPHY_FREQ: attributes.u32(),
+		NL80211_ATTR_WIPHY_CHANNEL_TYPE: attributes.u32(),
+		
+		#41 - 57
 		NL80211_ATTR_MGMT_SUBTYPE: attributes.u8(),
 		NL80211_ATTR_IE: attributes.binary(),
 		NL80211_ATTR_MAX_NUM_SCAN_SSIDS: attributes.u8(),
 		NL80211_ATTR_SCAN_FREQUENCIES: attributes.array(attributes.u32()),
 		NL80211_ATTR_SCAN_SSIDS: attributes.array(attributes.binary()),
 		NL80211_ATTR_GENERATION: attributes.u32(),
-		
-		#50 - 57
+		NL80211_ATTR_BSS: attributes.nested(ATTRIBUTES_BSS),
+		NL80211_ATTR_REG_INITIATOR: attributes.u8(),
+		NL80211_ATTR_REG_TYPE: attributes.u8(),
 		NL80211_ATTR_SUPPORTED_COMMANDS: attributes.array(attributes.u32(), base=1),
 		NL80211_ATTR_FRAME: attributes.binary(),
 		NL80211_ATTR_SSID: attributes.binary(),
@@ -1020,34 +1159,53 @@ class NL80211(generic.GenericNetlinkSocket):
 		NL80211_ATTR_MAX_SCAN_IE_LEN: attributes.u16(),
 		NL80211_ATTR_CIPHER_SUITES: attributes.binary(),
 		
-		#61 - 64
+		#61 - 66
 		NL80211_ATTR_WIPHY_RETRY_SHORT: attributes.u8(),
 		NL80211_ATTR_WIPHY_RETRY_LONG: attributes.u8(),
 		NL80211_ATTR_WIPHY_FRAG_THRESHOLD: attributes.u32(),
 		NL80211_ATTR_WIPHY_RTS_THRESHOLD: attributes.u32(),
+		NL80211_ATTR_TIMED_OUT: attributes.flag(),
+		NL80211_ATTR_USE_MFP: attributes.u32(),
 		
-		#83
+		#68
+		NL80211_ATTR_CONTROL_PORT: attributes.flag(),
+		
+		#70 - 83
+		NL80211_ATTR_PRIVACY: attributes.flag(),
+		NL80211_ATTR_DISCONNECTED_BY_AP: attributes.flag(),
+		NL80211_ATTR_STATUS_CODE: attributes.u16(),
+		NL80211_ATTR_CIPHER_SUITES_PAIRWISE: attributes.binary(),
+		NL80211_ATTR_CIPHER_SUITE_GROUP: attributes.u32(),
+		NL80211_ATTR_WPA_VERSIONS: attributes.u32(),
+		NL80211_ATTR_AKM_SUITES: attributes.binary(),
+		NL80211_ATTR_REQ_IE: attributes.binary(),
+		NL80211_ATTR_RESP_IE: attributes.binary(),
+		NL80211_ATTR_PREV_BSSID: attributes.binary(),
+		NL80211_ATTR_KEY: attributes.nested(ATTRIBUTES_KEY),
+		NL80211_ATTR_KEYS: attributes.array(attributes.nested(ATTRIBUTES_KEY)),
+		NL80211_ATTR_PID: attributes.u32(),
 		NL80211_ATTR_4ADDR: attributes.u8(),
 		
-		#86
+		#86 - 89
 		NL80211_ATTR_MAX_NUM_PMKIDS: attributes.u8(),
-		
-		#88 - 89
+		NL80211_ATTR_DURATION: attributes.u32(),
 		NL80211_ATTR_COOKIE: attributes.u64(),
 		NL80211_ATTR_WIPHY_COVERAGE_CLASS: attributes.u8(),
 		
-		#91
+		#91 - 92
 		NL80211_ATTR_FRAME_MATCH: attributes.binary(),
+		NL80211_ATTR_ACK: attributes.flag(),
 		
-		#98 - 100
+		#94
+		NL80211_ATTR_CQM: attributes.nested(ATTRIBUTES_CQM),
+		
+		#98 - 106
 		NL80211_ATTR_WIPHY_TX_POWER_LEVEL: attributes.u32(),
 		NL80211_ATTR_TX_FRAME_TYPES: attributes.dict(attributes.array(attributes.u16())),
 		NL80211_ATTR_RX_FRAME_TYPES: attributes.dict(attributes.array(attributes.u16())),
-		
-		#102
-		NL80211_ATTR_CONTROL_PORT_ETHERTYPE: attributes.flag(),
-		
-		#104 - 106
+		NL80211_ATTR_FRAME_TYPE: attributes.u16(),
+		NL80211_ATTR_CONTROL_PORT_ETHERTYPE: attributes.binary(), # flag or u16
+		NL80211_ATTR_CONTROL_PORT_NO_ENCRYPT: attributes.flag(),
 		NL80211_ATTR_SUPPORT_IBSS_RSN: attributes.flag(),
 		NL80211_ATTR_WIPHY_ANTENNA_TX: attributes.u32(),
 		NL80211_ATTR_WIPHY_ANTENNA_RX: attributes.u32(),
@@ -1070,44 +1228,55 @@ class NL80211(generic.GenericNetlinkSocket):
 		NL80211_ATTR_INTERFACE_COMBINATIONS: attributes.array(attributes.nested(ATTRIBUTES_IFACE_COMB), base=1),
 		NL80211_ATTR_SOFTWARE_IFTYPES: attributes.array(attributes.flag()),
 		
-		#123 - 125
+		#123 - 126
 		NL80211_ATTR_MAX_NUM_SCHED_SCAN_SSIDS: attributes.u8(),
 		NL80211_ATTR_MAX_SCHED_SCAN_IE_LEN: attributes.u16(),
 		NL80211_ATTR_SCAN_SUPP_RATES: attributes.dict(attributes.binary()),
+		NL80211_ATTR_HIDDEN_SSID: attributes.u32(),
 		
-		#130 - 131
+		#129 - 131
+		NL80211_ATTR_STA_WME: attributes.nested(ATTRIBUTES_STA_WME),
 		NL80211_ATTR_SUPPORT_AP_UAPSD: attributes.flag(),
 		NL80211_ATTR_ROAM_SUPPORT: attributes.flag(),
 		
 		#133
 		NL80211_ATTR_MAX_MATCH_SETS: attributes.u8(),
 		
-		#135
+		#135 - 137
 		NL80211_ATTR_TX_NO_CCK_RATE: attributes.flag(),
+		NL80211_ATTR_TDLS_ACTION: attributes.u8(),
+		NL80211_ATTR_TDLS_DIALOG_TOKEN: attributes.u8(),
 		
 		#139 - 140
 		NL80211_ATTR_TDLS_SUPPORT: attributes.flag(),
 		NL80211_ATTR_TDLS_EXTERNAL_SETUP: attributes.flag(),
 		
-		#143 - 144
+		#142 - 144
+		NL80211_ATTR_DONT_WAIT_FOR_ACK: attributes.flag(),
 		NL80211_ATTR_FEATURE_FLAGS: attributes.u32(),
 		NL80211_ATTR_PROBE_RESP_OFFLOAD: attributes.u32(),
 		
 		#148
 		NL80211_ATTR_HT_CAPABILITY_MASK: attributes.binary(),
 		
-		#153
+		#151 - 153
+		NL80211_ATTR_RX_SIGNAL_DBM: attributes.u32(),
+		NL80211_ATTR_BG_SCAN_PERIOD: attributes.u16(),
 		NL80211_ATTR_WDEV: attributes.u64(),
 		
-		#158
+		#158 - 161
 		NL80211_ATTR_SCAN_FLAGS: attributes.u32(),
+		NL80211_ATTR_CHANNEL_WIDTH: attributes.u32(),
+		NL80211_ATTR_CENTER_FREQ1: attributes.u32(),
+		NL80211_ATTR_CENTER_FREQ2: attributes.u32(),
 		
 		#166
 		NL80211_ATTR_MAC_ADDRS: attributes.array(attributes.binary(), base=1),
 		
-		#169 - 170
+		#169 - 171
 		NL80211_ATTR_EXT_CAPA: attributes.binary(),
 		NL80211_ATTR_EXT_CAPA_MASK: attributes.binary(),
+		NL80211_ATTR_STA_CAPABILITY: attributes.u16(),
 		
 		#174
 		NL80211_ATTR_SPLIT_WIPHY_DUMP: attributes.flag(),
@@ -1115,6 +1284,9 @@ class NL80211(generic.GenericNetlinkSocket):
 		#176
 		NL80211_ATTR_VHT_CAPABILITY_MASK: attributes.binary(),
 		
+		#189
+		NL80211_ATTR_STA_SUPPORTED_CHANNELS: attributes.binary(),
+		
 		#192 - 193
 		NL80211_ATTR_SUPPORT_5_MHZ: attributes.flag(),
 		NL80211_ATTR_SUPPORT_10_MHZ: attributes.flag(),
@@ -1123,13 +1295,14 @@ class NL80211(generic.GenericNetlinkSocket):
 		NL80211_ATTR_VENDOR_DATA: attributes.binary(), # Or nested (depends on command)
 		NL80211_ATTR_VENDOR_EVENTS: attributes.array(attributes.binary(), base=1),
 		
-		#202
+		#200 - 202
+		NL80211_ATTR_MAC_HINT: attributes.binary(),
+		NL80211_ATTR_WIPHY_FREQ_HINT: attributes.u32(),
 		NL80211_ATTR_MAX_AP_ASSOC_STA: attributes.u32(),
 		
-		#204
+		#204 - 206
 		NL80211_ATTR_SOCKET_OWNER: attributes.flag(),
-		
-		#206
+		NL80211_ATTR_CSA_C_OFFSETS_TX: attributes.binary(),
 		NL80211_ATTR_MAX_CSA_COUNTERS: attributes.u8(),
 		
 		#215 - 217
@@ -1145,7 +1318,9 @@ class NL80211(generic.GenericNetlinkSocket):
 		#229
 		NL80211_ATTR_PAD: attributes.padding(),
 		
-		#235 - 236
+		#233 - 236
+		NL80211_ATTR_SCAN_START_TIME_TSF: attributes.u64(),
+		NL80211_ATTR_SCAN_START_TIME_TSF_BSSID: attributes.binary(),
 		NL80211_ATTR_MEASUREMENT_DURATION: attributes.u16(),
 		NL80211_ATTR_MEASUREMENT_DURATION_MANDATORY: attributes.flag(),
 		
@@ -1155,17 +1330,44 @@ class NL80211(generic.GenericNetlinkSocket):
 		#245
 		NL80211_ATTR_BSSID: attributes.binary(),
 		
-		#256
-		NL80211_ATTR_SCHED_SCAN_MAX_REQS: attributes.u32(),
+		#248
+		NL80211_ATTR_TIMEOUT_REASON: attributes.u32(),
 		
-		#265 - 268
+		#254
+		NL80211_ATTR_PMK: attributes.binary(),
+		
+		#256 - 257
+		NL80211_ATTR_SCHED_SCAN_MAX_REQS: attributes.u32(),
+		NL80211_ATTR_WANT_1X_4WAY_HS: attributes.flag(),
+		
+		#264 - 268
+		NL80211_ATTR_CONTROL_PORT_OVER_NL80211: attributes.flag(),
 		NL80211_ATTR_TXQ_STATS: attributes.nested(ATTRIBUTES_TXQ_STATS),
 		NL80211_ATTR_TXQ_LIMIT: attributes.u32(),
 		NL80211_ATTR_TXQ_MEMORY_LIMIT: attributes.u32(),
 		NL80211_ATTR_TXQ_QUANTUM: attributes.u32(),
 		
+		#274
+		NL80211_ATTR_AIRTIME_WEIGHT: attributes.u16(),
+		
+		#277
+		NL80211_ATTR_SAE_PASSWORD: attributes.binary(),
+		
+		#280 - 281
+		NL80211_ATTR_WIPHY_EDMG_CHANNELS: attributes.u8(),
+		NL80211_ATTR_WIPHY_EDMG_BW_CONFIG: attributes.u8(),
+		
+		#286
+		NL80211_ATTR_CONTROL_PORT_NO_PREAUTH: attributes.flag(),
+		
+		#290
+		NL80211_ATTR_WIPHY_FREQ_OFFSET: attributes.u32(),
+		
 		#292
 		NL80211_ATTR_SCAN_FREQ_KHZ: attributes.array(attributes.u32()),
+		
+		#298
+		NL80211_ATTR_SAE_PWE: attributes.u8(),
 	})
 
 
